package Kubernetes::REST::Call::v1beta1::Authorization::GetAPIResources;
  use Moo;
  

  

  sub _url_params { [
  
  ] }

  sub _query_params { [
  
  ] }

  sub _url { '/apis/authorization.k8s.io/v1beta1/' }
  sub _method { 'GET' }
1;
